aboutsummaryrefslogtreecommitdiffstats
path: root/keyboards/rgbkb
diff options
context:
space:
mode:
authorXScorpion2 <rcalt2vt@gmail.com>2019-07-25 13:56:29 -0500
committerDrashna Jaelre <drashna@live.com>2019-07-25 11:56:29 -0700
commit20c0533c4c66b9d222b6ced2fad3ec6be6cad76e (patch)
tree2cceb641e573cafeb6ee68f5083fb532ab80cd93 /keyboards/rgbkb
parenta747953dfae85d3bdfdfe205fc3d4ae6f8d1fe05 (diff)
downloadfirmware-20c0533c4c66b9d222b6ced2fad3ec6be6cad76e.tar.gz
firmware-20c0533c4c66b9d222b6ced2fad3ec6be6cad76e.tar.bz2
firmware-20c0533c4c66b9d222b6ced2fad3ec6be6cad76e.zip
[User] Xulkal Keymaps Update (#6392)
* Xulkal changes Refactor rgb & encoder menu Hadron Keymap Refactor oled menu * Fixing horizontal OLED data display * Reverting changes to take to separate prs
Diffstat (limited to 'keyboards/rgbkb')
-rw-r--r--keyboards/rgbkb/sol/keymaps/xulkal/config.h31
-rw-r--r--keyboards/rgbkb/sol/keymaps/xulkal/keymap.c6
-rw-r--r--keyboards/rgbkb/sol/keymaps/xulkal/rules.mk10
3 files changed, 42 insertions, 5 deletions
diff --git a/keyboards/rgbkb/sol/keymaps/xulkal/config.h b/keyboards/rgbkb/sol/keymaps/xulkal/config.h
new file mode 100644
index 000000000..a5c35cfae
--- /dev/null
+++ b/keyboards/rgbkb/sol/keymaps/xulkal/config.h
@@ -0,0 +1,31 @@
+/*
+This is the c configuration file for the keymap
+
+Copyright 2012 Jun Wako <wakojun@gmail.com>
+Copyright 2015 Jack Humbert
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#pragma once
+
+// Xulkal custom stuff
+#if KEYBOARD_rgbkb_sol_rev2
+ #define OLED_90ROTATION
+ #define RGB_MATRIX_TOG_LAYERS
+ #define RGB_MATRIX_HUE_STEP 8
+ #define RGB_MATRIX_SAT_STEP 8
+ #define RGB_MATRIX_VAL_STEP 8
+ #define RGB_MATRIX_SPD_STEP 8
+#endif
diff --git a/keyboards/rgbkb/sol/keymaps/xulkal/rules.mk b/keyboards/rgbkb/sol/keymaps/xulkal/rules.mk
index 238d1cf23..6a14a99af 100644
--- a/keyboards/rgbkb/sol/keymaps/xulkal/rules.mk
+++ b/keyboards/rgbkb/sol/keymaps/xulkal/rules.mk
@@ -10,8 +10,14 @@ FULLHAND_ENABLE = yes # Enables the additional 24 Full Hand LEDs
# Misc
OLED_DRIVER_ENABLE = yes # Enable the OLED Driver
-
-
+# Not using the encoder for rev1
+ifeq ($(strip $(KEYBOARD)), rgbkb/sol/rev1)
+ ENCODER_ENABLE = no
+ RGB_OLED_MENU = no
+else
+ ENCODER_ENABLE = yes
+ RGB_OLED_MENU = 0
+endif
# Do not edit past here
diff --git a/keyboards/rgbkb/sol/keymaps/xulkal/keymap.c b/keyboards/rgbkb/sol/keymaps/xulkal/keymap.c
index e51edd907..c508b0ca8 100644
--- a/keyboards/rgbkb/sol/keymaps/xulkal/keymap.c
+++ b/keyboards/rgbkb/sol/keymaps/xulkal/keymap.c
@@ -21,7 +21,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |------+------+------+------+------+------+------| |------+------+------+------+------+------+------|
* | Sft[ | Z | X | C | V | B | RGB | |RGBRST| N | M | , | . | / | Sft] |
* |------+------+------+------+------+------+------| |------+------+------+------+------+------+------|
* | Ctl- | Win | LOWER| RAISE| Alt | Space|RGBRMOD| |RGBMOD| Space| Left | Up | Down | Right| Ctl= |
* |------+------+------+------+------+------+------| |------+------+------+------+------+------+------'
* | Space| DEL | | Enter| Space|
* `-------------' `-------------'
@@ -31,7 +31,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
_________________QWERTY_L2_________________, KC_LBRC, KC_RBRC, _________________QWERTY_R2_________________, \
_________________QWERTY_L3_________________, KC_GRV, KC_QUOT, _________________QWERTY_R3_________________, \
_________________QWERTY_L4_________________, RGB_TOG, RGBRST, _________________QWERTY_R4_________________, \
- _________________QWERTY_L5_________________, RGB_RMOD, RGB_MOD, _________________QWERTY_R5_________________, \
+ _________________QWERTY_L5_________________, KC_ENC1, KC_ENC2, _________________QWERTY_R5_________________, \
KC_SPC, TD_DEL, KC_ENT, KC_SPC \
),
@@ -41,7 +41,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
___________________GAME_L2_________________, KC_LBRC, KC_RBRC, ___________________GAME_R2_________________, \
___________________GAME_L3_________________, KC_GRV, KC_QUOT, ___________________GAME_R3_________________, \
___________________GAME_L4_________________, RGB_TOG, RGBRST, ___________________GAME_R4_________________, \
- ___________________GAME_L5_________________, RGB_RMOD, RGB_MOD, ___________________GAME_R5_________________, \
+ ___________________GAME_L5_________________, KC_ENC1, KC_ENC2, ___________________GAME_R5_________________, \
KC_SPC, KC_DEL, KC_ENT, KC_SPC \
),
#endif
@@ -21,7 +21,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | Sft[ | Z | X | C | V | B | RGB | |RGBRST| N | M | , | . | / | Sft] |
* |------+------+------+------+------+------+------| |------+------+------+------+------+------+------|
- * | Ctl- | Win | LOWER| RAISE| Alt | Space|RGBRMOD| |RGBMOD| Space| Left | Up | Down | Right| Ctl= |
+ * | Ctl- | Win | LOWER| RAISE| Alt | Space| ENC1 | | ENC2 | Space| Left | Up | Down | Right| Ctl= |
* |------+------+------+------+------+------+------| |------+------+------+------+------+------+------'
* | Space| DEL | | Enter| Space|